==> trading-backend-1.0.14.tar.gz: trading-backend-1.0.14/trading_backend/exchanges/bybit.py <==
#  Drakkar-Software trading-backend
#  Copyright (c) Drakkar-Software, All rights reserved.
#
#  This library is free software; you can redistribute it and/or
#  modify it under the terms of the GNU Lesser General Public
#  License as published by the Free Software Foundation; either
#  version 3.0 of the License, or (at your option) any later version.
#
#  This library is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
#  Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General Public
#  License along with this library.
import trading_backend.exchanges as exchanges


class Bybit(exchanges.Exchange):
    SPOT_ID = "octobot"
    MARGIN_ID = None
    FUTURE_ID = "octobot"
    IS_SPONSORING = True
    HEADER_SPOT_KEY = "agentSource"
    HEADER_FUTURE_KEY = "tag"

    @classmethod
    def get_name(cls):
        return 'bybit'

    def get_headers(self):
        return {self.HEADER_FUTURE_KEY: self._get_id()} if self._exchange.exchange_manager.is_future else {}

    def get_orders_parameters(self, params=None) -> dict:
        params = super().get_orders_parameters(params)
        if not self._exchange.exchange_manager.is_future and not self._exchange.exchange_manager.is_margin:
            params.update({self.HEADER_SPOT_KEY: self._get_id()})
        return params

    async def _inner_is_valid_account(self) -> (bool, str):
        # Nothing to do
        return await super()._inner_is_valid_account()

==> trading-backend-1.0.19.tar.gz: trading-backend-1.0.19/trading_backend/exchanges/bybit.py <==
#  Drakkar-Software trading-backend
#  Copyright (c) Drakkar-Software, All rights reserved.
#
#  This library is free software; you can redistribute it and/or
#  modify it under the terms of the GNU Lesser General Public
#  License as published by the Free Software Foundation; either
#  version 3.0 of the License, or (at your option) any later version.
#
#  This library is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
#  Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General Public
#  License along with this library.
import trading_backend.exchanges as exchanges


class Bybit(exchanges.Exchange):
    SPOT_ID = "octobot"
    MARGIN_ID = "octobot"
    FUTURE_ID = "octobot"
    IS_SPONSORING = True
    HEADER_SPOT_KEY = "agentSource"
    HEADER_FUTURE_KEY = "Referer"

    @classmethod
    def get_name(cls):
        return 'bybit'

    def get_headers(self):
        return {self.HEADER_FUTURE_KEY: self._get_id()} if self._exchange.exchange_manager.is_future else {}

    def get_orders_parameters(self, params=None) -> dict:
        if self._exchange.connector.client.options.get("brokerId", None) != self._get_id():
            self._exchange.connector.client.options["brokerId"] = self._get_id()
        return super().get_orders_parameters(params)

    async def _inner_is_valid_account(self) -> (bool, str):
        # Nothing to do
        return await super()._inner_is_valid_account()
